@@ -9,7 +9,7 @@ from functools import partial
 from ..http import Request, Response
 from .. import environ
 from ..call import Router, Call
-from ..decorators import _property
+from ..decorators import property
 from ..exception import CallError, Redirect, CallStop, AccessDenied
 from ..utils import ByteString, JSONEncoder
 
@@ -83,7 +83,7 @@ class BaseServer(object):
         """Return host:port string that the server is using to answer requests"""
         raise NotImplementedError()
 
-    @_property
+    @property(cached="_backend")
     def backend(self):
         ret = self.create_backend()
         return ret
@@ -127,27 +127,6 @@ class BaseServer(object):
     def create_request_body(self, request, raw_request, **kwargs):
         raise NotImplementedError()
 
-    def get_request_body_json(self, body, **kwargs):
-        """Returns the body args and kwargs from a json body
-
-        :param body: string, the json body
-        :param **kwargs:
-        :returns: list, dict, the args and kwargs ready to be set into Request
-        """
-        body_args = []
-        body_kwargs = {}
-        b = json.loads(body)
-        if isinstance(b, list):
-            body_args = b
-
-        elif isinstance(b, dict):
-            body_kwargs = b
-
-        else:
-            body_args = [b]
-
-        return body_args, body_kwargs
-
     def create_response(self, **kwargs):
         """create the endpoints understandable response instance that is used to
         return output to the client"""
